==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/gods/dialogs_it.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Ho il sospetto che scopriremo qualcosa di orribile.")

dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("L'ho sempre saputo: gli dei devono essere impazziti.")

dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Dio è pazzo e tutto il mondo è solo il suo giocattolo.")

dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Penso che tu abbia ragione.")

dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Temo che tu abbia ragione.")

dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Sì, è scioccante.")

dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Cosa possiamo fare?")

dialogId("lod-v-internovat", "font_big", "We can`t leave it this way. We must incarcerate them.")
dialogStr("Non possiamo lasciar correre. Dobbiamo rinchiuderli.")

dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Cosa dobbiamo fare?")

dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Metterli in mani... volevo dire in mano ai nostri agenti di sicurezza alla FDTO.")

dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Giusto. Tutti e due?")

dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Certamente. Se ne lasciami qui uno, chissà che idea pazza potrebbe venirgli. Potrebbe mettersi a giocare a golf, per esempio.")
dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Difficilmente, con questa mazza. Dovremmo ritenerci soddisfatti se ne prendiamo anche solo uno. Allora l'altro sarà innocuo.")

dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Bene. Quale?")

dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Quello giallo.")

dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Quello blu.")

dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Quello giallo.")

dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Quello blu.")

dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Lasciamo decidere il giocatore.")

dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Dovrebbe decidere il giocatore.")

dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Guarda quella mazza: qualcosa di terribile è successo.")

dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Probabilmente un pld se l'è sgranocchiata.")

dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mia madre aveva ragione. La troppa giocosità è la radice di tutti i mali.")

dialogId("lod-m-palka", "font_small", "That`s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("È vero. Sarebbe molto più facile se quella racchetta da ping-pong non fosse stata lì.")

dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Tra l'altro, hai notato che la vera pallina da golf si trova nell'angolo in alto a sinistra, mentre quella nell'angolo inferiore destro è una pallina da cricket?")

dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Ci sarà qualche sorta di simbolismo in ciò?")

dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Chi lo sa!")

dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Pensavo che quella lassù fosse una pallina da ping-pong.")

dialogId("lod-v-rozliseni", "font_big", "It`s hard to say with this screen resolution.")
dialogStr("Difficile a dirsi, con questa risoluzione dello schermo.")

dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Questa volta il nostro obiettivo è portare fuori una di queste divinità.")

dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Zásah!")

dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Colpito!")

dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Colpito!")

dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Colpito!")

dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Vyhrál jsem, saláte!!!")

dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Comincio io!")

dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Bene!")

dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Un'altra?")

dialogId("b1-nepodvadim", "font_yellow", "I don`t cheat.")
dialogStr("Io non imbroglio!!!")

dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("È stato uno sbaglio, forse...")

dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ah ah ah ah... ho vinto!")

dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Bene!")

dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Ne facciamo un'altra?")

dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Questa era `un'altra'!")

dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("L'hai già chiesto!")

dialogId("b2-nemuze", "font_cyan", "It can`t be a miss on this space.")
dialogStr("Non può essere acqua qui!")

dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Tu imbrogli!!!")

dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss`!")
dialogStr("Ho provato - e tu hai detto `acqua'!")

dialogId("b1-1", "", "")
dialogStr("")

dialogId("b1-2", "", "")
dialogStr("")

dialogId("b1-3", "", "")
dialogStr("")

dialogId("b1-4", "", "")
dialogStr("")

dialogId("b1-5", "", "")
dialogStr("")

dialogId("b1-6", "", "")
dialogStr("")

dialogId("b1-7", "", "")
dialogStr("")

dialogId("b1-8", "", "")
dialogStr("")

dialogId("b1-9", "", "")
dialogStr("")

dialogId("b1-10", "", "")
dialogStr("")

dialogId("b1-a", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-b", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-c", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-d", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-e", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-f", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-g", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-h", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-i", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-j", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b2-1", "", "")
dialogStr("")

dialogId("b2-2", "", "")
dialogStr("")

dialogId("b2-3", "", "")
dialogStr("")

dialogId("b2-4", "", "")
dialogStr("")

dialogId("b2-5", "", "")
dialogStr("")

dialogId("b2-6", "", "")
dialogStr("")

dialogId("b2-7", "", "")
dialogStr("")

dialogId("b2-8", "", "")
dialogStr("")

dialogId("b2-9", "", "")
dialogStr("")

dialogId("b2-10", "", "")
dialogStr("")

dialogId("b2-a", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-b", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-c", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-d", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-e", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-f", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-g", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-h", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-i", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-j", "font_cyan", "%1.")
dialogStr("%1.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/gods/dialogs_it.lua <==

dialogId("lod-v-silenost0", "font_big", "I have a suspicion that we are about to discover something terrible.")
dialogStr("Ho il sospetto che scopriremo qualcosa di orribile.")

dialogId("lod-v-silenost1", "font_big", "I always knew that: the gods must be mad.")
dialogStr("L'ho sempre saputo: gli dei devono essere impazziti.")

dialogId("lod-v-silenost2", "font_big", "God is mad and the whole world is his plaything.")
dialogStr("Dio è pazzo e tutto il mondo è solo il suo giocattolo.")

dialogId("lod-m-pravda0", "font_small", "I think that you are right.")
dialogStr("Penso che tu abbia ragione.")

dialogId("lod-m-pravda1", "font_small", "I am afraid that you are right.")
dialogStr("Temo che tu abbia ragione.")

dialogId("lod-m-pravda2", "font_small", "Yes, it is shocking.")
dialogStr("Sì, è scioccante.")

dialogId("lod-m-costim", "font_small", "What are we to do about it?")
dialogStr("Cosa possiamo fare?")

dialogId("lod-v-internovat", "font_big", "We can’t leave it this way. We must incarcerate them.")
dialogStr("Non possiamo lasciar correre. Dobbiamo rinchiuderli.")

dialogId("lod-m-co", "font_small", "What must we do?")
dialogStr("Cosa dobbiamo fare?")

dialogId("lod-v-cvok", "font_big", "Put them into the mad... I mean into the detainment facility of FDTO.")
dialogStr("Metterli in mani... volevo dire in mano ai nostri agenti di sicurezza alla FDTO.")

dialogId("lod-m-oba", "font_small", "You are right. Shall we take both of them?")
dialogStr("Giusto. Tutti e due?")

dialogId("lod-v-golf", "font_big", "Of course. If we leave one of them here, any mad idea could occur to him. He could try to start playing golf, for example.")
dialogStr("Certamente. Se ne lasciami qui uno, chissà che idea pazza potrebbe venirgli. Potrebbe mettersi a giocare a golf, per esempio.")
dialogId("lod-m-jednoho", "font_small", "Hardly with this club. I think we should be happy if we manage to get one. The other one will be harmless then.")
dialogStr("Difficilmente, con questa mazza. Dovremmo ritenerci soddisfatti se ne prendiamo anche solo uno. Allora l'altro sarà innocuo.")

dialogId("lod-v-koho", "font_big", "Well. Which one?")
dialogStr("Bene. Quale?")

dialogId("lod-m-zluty", "font_small", "The yellow one.")
dialogStr("Quello giallo.")

dialogId("lod-m-modry", "font_small", "The blue one.")
dialogStr("Quello blu.")

dialogId("lod-v-zluty", "font_big", "That yellow one.")
dialogStr("Quello giallo.")

dialogId("lod-v-modry", "font_big", "That blue one.")
dialogStr("Quello blu.")

dialogId("lod-m-hrac", "font_small", "We will leave this to the player.")
dialogStr("Lasciamo decidere il giocatore.")

dialogId("lod-v-hrac", "font_big", "We shall leave this to the player.")
dialogStr("Dovrebbe decidere il giocatore.")

dialogId("lod-v-hul", "font_big", "Look at that club: something terrible happened to it.")
dialogStr("Guarda quella mazza: qualcosa di terribile è successo.")

dialogId("lod-m-ozizlana", "font_small", "A pld probably sucked upon it.")
dialogStr("Probabilmente un pld se l'è sgranocchiata.")

dialogId("lod-v-hravost", "font_big", "Mother was right. Abnormal playfulness is the root of all evil.")
dialogStr("Mia madre aveva ragione. La troppa giocosità è la radice di tutti i mali.")

dialogId("lod-m-palka", "font_small", "That’s true. It would be much easier if that table tennis bat was somewhere else.")
dialogStr("È vero. Sarebbe molto più facile se quella racchetta da ping-pong non fosse stata lì.")

dialogId("lod-v-micky", "font_big", "By the way, did you notice that the real golf ball is in the upper left corner while that thing in the lower right corner is a cricket ball?")
dialogStr("Tra l'altro, hai notato che la vera pallina da golf si trova nell'angolo in alto a sinistra, mentre quella nell'angolo inferiore destro è una pallina da cricket?")

dialogId("lod-m-vyznam", "font_small", "Is there some hidden symbolism?")
dialogStr("Ci sarà qualche sorta di simbolismo in ciò?")

dialogId("lod-v-kdovi", "font_big", "Who knows.")
dialogStr("Chi lo sa!")

dialogId("lod-m-micek", "font_small", "I thought it was a table tennis ball up there.")
dialogStr("Pensavo che quella lassù fosse una pallina da ping-pong.")

dialogId("lod-v-rozliseni", "font_big", "It’s hard to say with this screen resolution.")
dialogStr("Difficile a dirsi, con questa risoluzione dello schermo.")

dialogId("lod-m-bohove", "font_small", "This time our goal is to get out one of those gods.")
dialogStr("Questa volta il nostro obiettivo è portare fuori una di queste divinità.")

dialogId("b1-voda1", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda2", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda3", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda4", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-voda5", "font_yellow", "Miss!")
dialogStr("Acqua!")

dialogId("b1-zasah1", "font_yellow", "Hit!")
dialogStr("Zásah!")

dialogId("b1-zasah2", "font_yellow", "Hit!")
dialogStr("Colpito!")

dialogId("b1-zasah3", "font_yellow", "Hit!")
dialogStr("Colpito!")

dialogId("b1-zasah4", "font_yellow", "Hit!")
dialogStr("Colpito!")

dialogId("b1-potop1", "font_yellow", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b1-potop2", "font_yellow", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b1-potop3", "font_yellow", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b1-vyhral", "font_yellow", "I won, you sissy!!!")
dialogStr("Vyhrál jsem, saláte!!!")

dialogId("b1-zacinam", "font_yellow", "I start!")
dialogStr("Comincio io!")

dialogId("b1-dobre", "font_yellow", "Well!")
dialogStr("Bene!")

dialogId("b1-znovu", "font_yellow", "Shall we play another one?")
dialogStr("Un'altra?")

dialogId("b1-nepodvadim", "font_yellow", "I don’t cheat.")
dialogStr("Io non imbroglio!!!")

dialogId("b1-spletl", "font_yellow", "It was a mistake, probably...")
dialogStr("È stato uno sbaglio, forse...")

dialogId("b2-voda1", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda2", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda3", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda4", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-voda5", "font_cyan", "Miss!")
dialogStr("Acqua!")

dialogId("b2-zasah1", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-zasah2", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-zasah3", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-zasah4", "font_cyan", "Hit!")
dialogStr("Colpito!")

dialogId("b2-potop1", "font_cyan", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b2-potop2", "font_cyan", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b2-potop3", "font_cyan", "Sank!")
dialogStr("Colpito e affondato!")

dialogId("b2-vyhral", "font_cyan", "He, he, he... I won!")
dialogStr("Ah ah ah ah... ho vinto!")

dialogId("b2-dobre", "font_cyan", "Well!")
dialogStr("Bene!")

dialogId("b2-znovu", "font_cyan", "Shall we try it again?")
dialogStr("Ne facciamo un'altra?")

dialogId("b2-rikal1", "font_cyan", "You already tried this!")
dialogStr("Questa era ’un'altra'!")

dialogId("b2-rikal2", "font_cyan", "You already said that!")
dialogStr("L'hai già chiesto!")

dialogId("b2-nemuze", "font_cyan", "It can’t be a miss on this space.")
dialogStr("Non può essere acqua qui!")

dialogId("b2-podvadis", "font_cyan", "You cheat!!!")
dialogStr("Tu imbrogli!!!")

dialogId("b2-spatne", "font_cyan", "I have tried that - and you said 'miss’!")
dialogStr("Ho provato - e tu hai detto ’acqua'!")

dialogId("b1-1", "", "")
dialogStr("")

dialogId("b1-2", "", "")
dialogStr("")

dialogId("b1-3", "", "")
dialogStr("")

dialogId("b1-4", "", "")
dialogStr("")

dialogId("b1-5", "", "")
dialogStr("")

dialogId("b1-6", "", "")
dialogStr("")

dialogId("b1-7", "", "")
dialogStr("")

dialogId("b1-8", "", "")
dialogStr("")

dialogId("b1-9", "", "")
dialogStr("")

dialogId("b1-10", "", "")
dialogStr("")

dialogId("b1-a", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-b", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-c", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-d", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-e", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-f", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-g", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-h", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-i", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b1-j", "font_yellow", "%1.")
dialogStr("%1.")

dialogId("b2-1", "", "")
dialogStr("")

dialogId("b2-2", "", "")
dialogStr("")

dialogId("b2-3", "", "")
dialogStr("")

dialogId("b2-4", "", "")
dialogStr("")

dialogId("b2-5", "", "")
dialogStr("")

dialogId("b2-6", "", "")
dialogStr("")

dialogId("b2-7", "", "")
dialogStr("")

dialogId("b2-8", "", "")
dialogStr("")

dialogId("b2-9", "", "")
dialogStr("")

dialogId("b2-10", "", "")
dialogStr("")

dialogId("b2-a", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-b", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-c", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-d", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-e", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-f", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-g", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-h", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-i", "font_cyan", "%1.")
dialogStr("%1.")

dialogId("b2-j", "font_cyan", "%1.")
dialogStr("%1.")
